@@ -5,63 +5,45 @@ use vars qw($Debug);
 use BSD::Resource qw(setrlimit getrlimit get_rlimits);
 
 $Debug ||= 0;
-$Apache::Resource::VERSION = (qw$Revision: 1.13 $)[1];
+$Apache::Resource::VERSION = (qw$Revision: 1.11 $)[1];
 
-sub MB ($) { 
-    my $num = shift;
-    if($num < (1024 * 1024)) {
-	return $num*1024*1024;
-    }
-    $num;
-}
+sub MB ($) { $_[0]*1024*1024 }
 
-sub DEFAULT_RLIMIT_DATA  () { 64 } #data (memory) size
-sub DEFAULT_RLIMIT_CPU   () { 60*3 } #cpu time in milliseconds
-sub DEFAULT_RLIMIT_CORE  () { 0  } #core file size
-sub DEFAULT_RLIMIT_RSS   () { 16 } #resident set size
-sub DEFAULT_RLIMIT_FSIZE () { 10 } #file size 
-sub DEFAULT_RLIMIT_STACK () { 20 } #stack size
-
-my %is_mb = map {$_,1} qw{DATA RSS STACK FSIZE};
-
-sub debug { print STDERR @_ if $Debug }
+sub DEFAULT_RLIMIT_DATA () { MB 64 } #data (memory) size
+sub DEFAULT_RLIMIT_CPU  () { 30 }     #cpu time in milliseconds
+sub DEFAULT_RLIMIT_CORE () { 0 }      #core file size
+sub DEFAULT_RLIMIT_RSS   () { MB 16 } #resident set size
 
 sub install_rlimit ($$$) {
     my($res, $soft, $hard) = @_;
 
-    my $name = $res;
-
     my $cv = \&{"BSD::Resource::RLIMIT_${res}"};
-    eval { $res = $cv->() };
+    eval { $res = &{$cv}() };
     return if $@;
 
     unless ($soft) { 
-	my $defval = \&{"DEFAULT_RLIMIT_${name}"};
-	if(defined &$defval) {
-	    $soft = $defval->();
-	}
-	else {
-	    warn "can't find default for `$defval'\n";
-	}
+	my $defval = \&{"DEFAULT_RLIMIT_${res}"};
+	$soft = &$defval if defined &$defval;
     }
 
     $hard ||= $soft;
 
-    debug "Apache::Resource: attempting to set `$name'=$soft:$hard ...";
-
-    ($soft, $hard) = (MB $soft, MB $hard) if $is_mb{$name};
-
     return setrlimit $res, $soft, $hard;
 }
 
+#limit memory hogging by default
+$ENV{PERL_RLIMIT_DATA} ||= DEFAULT_RLIMIT_DATA;
+
+sub debug { print STDERR @_ if $Debug }
+
 sub handler {
     while(my($k,$v) = each %ENV) {
 	next unless $k =~ /^PERL_RLIMIT_(\w+)$/;
 	$k = $1;
-	next if $k eq "DEFAULTS";
 	my($soft, $hard) = split ":", $v, 2; 
 	$hard ||= $soft;
 
+	debug "Apache::Resource: attempting to set `$k'=$soft:$hard ...";
 	my $set = install_rlimit $k, $soft, $hard;
 	debug "not " unless $set;
 	debug "ok\n";
@@ -71,14 +53,6 @@ sub handler {
     0;
 }
 
-sub default_handler {
-    while(my($k,$v) = each %Apache::Resource::) {
-	next unless $k =~ s/^DEFAULT_/PERL_/;
-	$ENV{$k} = "";
-    }
-    handler();
-}
-
 sub status_rlimit {
     my $lim = get_rlimits();
     my @retval = ("<table border=1><tr>", 
@@ -98,18 +72,12 @@ sub status_rlimit {
     return \@retval;
 }
 
-if($ENV{MOD_PERL}) {
-    if($ENV{PERL_RLIMIT_DEFAULTS}) {
-	Apache->push_handlers(PerlChildInitHandler => \&default_handler);
-    }
-
-    Apache::Status->menu_item(rlimit => "Resource Limits", 
-			    \&status_rlimit)
-      if Apache->module("Apache::Status");
-}
+Apache::Status->menu_item(rlimit => "Resource Limits", 
+			  \&status_rlimit)
+    if $INC{"Apache/Status.pm"};
 
 #perl Apache/Resource.pm
-++$Debug, default_handler unless caller();
+++$Debug, handler unless caller();
 
 1;
 
@@ -128,8 +96,8 @@ Apache::Resource - Limit resources used by httpd children
  PerlSetEnv PERL_DATA_LIMIT 35
 
  #set cpu limit in milliseconds
- #default is 60 milliseconds
- PerlSetEnv PERL_RLIMIT_CPU 120
+ #default is 30 milliseconds
+ PerlSetEnv PERL_RLIMIT_CPU 20
 
  PerlChildInitHandler Apache::Resource
 
